pub struct NativeMacosProductConfig {
pub scheme: String,
pub bundle: String,
pub kind: NativeMacosProductKind,
pub package: bool,
pub entitlements: Option<String>,
pub provisioning_profile: Option<String>,
pub signing_identity: Option<String>,
pub run: NativeMacosProductSigningConfig,
}Fields
scheme: Stringbundle: Stringkind: NativeMacosProductKindpackage: boolControls whether fission package builds and embeds this product.
fission build and fission run always include configured products.
entitlements: Option<String>provisioning_profile: Option<String>signing_identity: Option<String>run: NativeMacosProductSigningConfigTrait Implementations
Sourceimpl Clone for NativeMacosProductConfig
impl Clone for NativeMacosProductConfig
Sourcefn clone(&self) -> NativeMacosProductConfig
fn clone(&self) -> NativeMacosProductConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NativeMacosProductConfig
impl Debug for NativeMacosProductConfig
Sourceimpl<'de> Deserialize<'de> for NativeMacosProductConfig
impl<'de> Deserialize<'de> for NativeMacosProductConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for NativeMacosProductConfig
Sourceimpl PartialEq for NativeMacosProductConfig
impl PartialEq for NativeMacosProductConfig
Sourceimpl Serialize for NativeMacosProductConfig
impl Serialize for NativeMacosProductConfig
impl StructuralPartialEq for NativeMacosProductConfig